@@ -194,7 +194,7 @@ class SimpleImputer():
                         self.X[i,self.column] = float(mean)
             return self.X
 
-class BFFImputer():
+class DGImputer():
     def evaluate(self, pos):
         import numpy as np
         self.diffs = np.zeros(shape=self.X.shape)
@@ -219,7 +219,7 @@ class BFFImputer():
         self.nans = []
         self.diffs = np.zeros(shape=self.X.shape)
         self.scores = np.zeros(shape=(self.X.shape[0], 1))
-        self.friends = []
+        self.dg = []
         
         for i in range(len(self.X[0,:])):
             if type(self.X[0,i]) == str:
@@ -231,7 +231,13 @@ class BFFImputer():
                 self.nans.append((i,self.col))
         
         for i in range(len(self.nans)):
-            self.friends = self.evaluate(self.nans[i])
-            self.X[self.nans[i][0], self.nans[i][1]] = self.X[self.friends[0][0], self.col]
+            if np.nanstd(self.X[:,self.col]) > 5:
+                self.dg = self.evaluate(self.nans[i])
+                self.dg_vals = [self.X[self.evaluate(self.nans[i]), self.col]]
+                self.dg_mean = np.mean(np.array([self.dg_vals[0][0], self.dg_vals[0][1], self.dg_vals[0][2]]))
+                self.X[self.nans[i][0], self.nans[i][1]] = self.dg_mean
+            else:
+                self.dg = self.evaluate(self.nans[i])
+                self.X[self.nans[i][0], self.nans[i][1]] = self.X[self.dg[0][0], self.col]
            
         return self.X
\ No newline at end of file
